@@ -41,16 +41,13 @@ import htsjdk.tribble.index.tabix.TabixIndex;
 import htsjdk.tribble.index.tabix.TabixIndexCreator;
 import htsjdk.tribble.readers.PositionalBufferedStream;
 import htsjdk.tribble.util.LittleEndianInputStream;
-import htsjdk.tribble.util.LittleEndianOutputStream;
 import htsjdk.tribble.util.ParsingUtils;
 import htsjdk.tribble.util.TabixUtils;
 
 import java.io.BufferedInputStream;
-import java.io.BufferedOutputStream;
 import java.io.File;
 import java.io.FileInputStream;
 import java.io.FileNotFoundException;
-import java.io.FileOutputStream;
 import java.io.IOException;
 import java.io.InputStream;
 import java.lang.reflect.Constructor;
@@ -288,18 +285,11 @@ public class IndexFactory {
      * @param idx
      * @param idxFile
      * @throws IOException
+     * @deprecated use {@link Index#write(File)} instead
      */
+    @Deprecated
     public static void writeIndex(final Index idx, final File idxFile) throws IOException {
-        LittleEndianOutputStream stream = null;
-        try {
-            stream = new LittleEndianOutputStream(new BufferedOutputStream(new FileOutputStream(idxFile)));
-            idx.write(stream);
-        }
-        finally {
-            if(stream != null) {
-                stream.close();
-            }
-        }
+        idx.write(idxFile);
     }
 
     /**
@@ -355,8 +345,8 @@ public class IndexFactory {
 
             checkSorted(inputFile, lastFeature, currentFeature);
             //should only visit chromosomes once
-            final String curChr = currentFeature.getChr();
-            final String lastChr = lastFeature != null ? lastFeature.getChr() : null;
+            final String curChr = currentFeature.getContig();
+            final String lastChr = lastFeature != null ? lastFeature.getContig() : null;
             if(!curChr.equals(lastChr)){
                 if(visitedChromos.containsKey(curChr)){
                     String msg = "Input file must have contiguous chromosomes.";
@@ -379,15 +369,15 @@ public class IndexFactory {
     }
 
     private static String featToString(final Feature feature){
-        return feature.getChr() + ":" + feature.getStart() + "-" + feature.getEnd();
+        return feature.getContig() + ":" + feature.getStart() + "-" + feature.getEnd();
     }
 
     private static void checkSorted(final File inputFile, final Feature lastFeature, final Feature currentFeature){
         // if the last currentFeature is after the current currentFeature, exception out
-        if (lastFeature != null && currentFeature.getStart() < lastFeature.getStart() && lastFeature.getChr().equals(currentFeature.getChr()))
+        if (lastFeature != null && currentFeature.getStart() < lastFeature.getStart() && lastFeature.getContig().equals(currentFeature.getContig()))
             throw new TribbleException.MalformedFeatureFile("Input file is not sorted by start position. \n" +
-                    "We saw a record with a start of " + currentFeature.getChr() + ":" + currentFeature.getStart() +
-                    " after a record with a start of " + lastFeature.getChr() + ":" + lastFeature.getStart(), inputFile.getAbsolutePath());
+                    "We saw a record with a start of " + currentFeature.getContig() + ":" + currentFeature.getStart() +
+                    " after a record with a start of " + lastFeature.getContig() + ":" + lastFeature.getStart(), inputFile.getAbsolutePath());
     }
 
 
